# Authors

Clay is written and maintained by the Lúcuma Team and various contributors.


Project Leader / Developer:

- Juan-Pablo Scaletti <juanpablo@lucumalabs.com>


Contributors:

- Muhammad Alkarouri (https://github.com/malkarouri)

